<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh-CN" sourcelanguage="en">
  <context>
    <name>CmdDrawingAnnotation</name>
    <message>
      <location filename="../../Command.cpp" line="481"/>
      <source>Drawing</source>
      <translation>图纸</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="482"/>
      <source>&amp;Annotation</source>
      <translation>注释(&amp;A)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="483"/>
      <location filename="../../Command.cpp" line="485"/>
      <source>Inserts an Annotation view in the active drawing</source>
      <translation>在当前制图中插入注释视图</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingClip</name>
    <message>
      <location filename="../../Command.cpp" line="529"/>
      <source>Drawing</source>
      <translation>图纸</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="530"/>
      <source>&amp;Clip</source>
      <translation>剪裁(&amp;C)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="531"/>
      <location filename="../../Command.cpp" line="533"/>
      <source>Inserts a clip group in the active drawing</source>
      <translation>在当前图纸中插入剪辑组</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingDraftView</name>
    <message>
      <location filename="../../Command.cpp" line="728"/>
      <source>Drawing</source>
      <translation>图纸</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="729"/>
      <source>&amp;Draft View</source>
      <translation>草图视图(&amp;D)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="730"/>
      <location filename="../../Command.cpp" line="732"/>
      <source>Inserts a Draft view of the selected object(s) in the active drawing</source>
      <translation>在当前图纸中插入所选对象的工程图视图</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingExportPage</name>
    <message>
      <location filename="../../Command.cpp" line="635"/>
      <source>File</source>
      <translation>文件</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="636"/>
      <source>&amp;Export page...</source>
      <translation>导出页(&amp;E)...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="637"/>
      <location filename="../../Command.cpp" line="639"/>
      <source>Export a page to an SVG file</source>
      <translation>将页面导出为SVG文件</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewA3Landscape</name>
    <message>
      <location filename="../../Command.cpp" line="275"/>
      <source>Drawing</source>
      <translation>图纸</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="276"/>
      <location filename="../../Command.cpp" line="277"/>
      <source>Insert new A3 landscape drawing</source>
      <translation>插入A3横向图框</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewPage</name>
    <message>
      <location filename="../../Command.cpp" line="97"/>
      <source>Drawing</source>
      <translation>图纸</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="98"/>
      <location filename="../../Command.cpp" line="99"/>
      <source>Insert new drawing</source>
      <translation>插入新视图</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewView</name>
    <message>
      <location filename="../../Command.cpp" line="314"/>
      <source>Drawing</source>
      <translation>图纸</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="315"/>
      <source>Insert view in drawing</source>
      <translation>在图纸中插入视图</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="316"/>
      <source>Insert a new View of a Part in the active drawing</source>
      <translation>在当前图纸中插入一个零件视图</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOpen</name>
    <message>
      <location filename="../../Command.cpp" line="60"/>
      <source>Drawing</source>
      <translation>图纸</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="61"/>
      <source>Open SVG...</source>
      <translation>打开SVG...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="62"/>
      <source>Open a scalable vector graphic</source>
      <translation>打开一个可缩放的矢量图形</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOpenBrowserView</name>
    <message>
      <location filename="../../Command.cpp" line="443"/>
      <source>Drawing</source>
      <translation>图纸</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="444"/>
      <source>Open &amp;browser view</source>
      <translation>打开浏览器视图(&amp;B)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="445"/>
      <location filename="../../Command.cpp" line="447"/>
      <source>Opens the selected page in a browser view</source>
      <translation>在浏览器视图中打开选定页面</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOrthoViews</name>
    <message>
      <location filename="../../Command.cpp" line="393"/>
      <source>Drawing</source>
      <translation>图纸</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="394"/>
      <source>Insert orthographic views</source>
      <translation>插入正交视图</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="395"/>
      <source>Insert an orthographic projection of a part in the active drawing</source>
      <translation>在当前图纸中插入零件的正交投影</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingProjectShape</name>
    <message>
      <location filename="../../Command.cpp" line="692"/>
      <source>Drawing</source>
      <translation>图纸</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="693"/>
      <source>Project shape...</source>
      <translation>投影形体...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="694"/>
      <location filename="../../Command.cpp" line="695"/>
      <source>Project shape onto a user-defined plane</source>
      <translation>投影形体至用户定义平面</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingSpreadsheetView</name>
    <message>
      <location filename="../../Command.cpp" line="759"/>
      <source>Drawing</source>
      <translation>图纸</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="760"/>
      <source>&amp;Spreadsheet View</source>
      <translation>表格视图(&amp;S)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="761"/>
      <location filename="../../Command.cpp" line="763"/>
      <source>Inserts a view of a selected spreadsheet in the active drawing</source>
      <translation>在当前图纸中将所选表格作为一个视图插入</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingSymbol</name>
    <message>
      <location filename="../../Command.cpp" line="574"/>
      <source>Drawing</source>
      <translation>图纸</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="575"/>
      <source>&amp;Symbol</source>
      <translation>符号(&amp;S)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="576"/>
      <location filename="../../Command.cpp" line="578"/>
      <source>Inserts a symbol from a svg file in the active drawing</source>
      <translation>在当前图纸中将 svg 文件内容作为一个符号插入</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::DrawingView</name>
    <message>
      <location filename="../../DrawingView.cpp" line="219"/>
      <source>&amp;Background</source>
      <translation>背景(&amp;B)</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="225"/>
      <source>&amp;Outline</source>
      <translation>轮廓(&amp;O)</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="231"/>
      <source>&amp;Native</source>
      <translation>本地(&amp;N) </translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="235"/>
      <source>&amp;OpenGL</source>
      <translation>&amp;OpenGL</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="238"/>
      <source>&amp;Image</source>
      <translation>图片(&amp;I)</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="242"/>
      <source>&amp;High Quality Antialiasing</source>
      <translation>高品质抗锯齿(&amp;H)</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="284"/>
      <source>Open SVG File</source>
      <translation>打开SVG文件</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="285"/>
      <source>Could not open file '%1'.</source>
      <translation>无法打开文件'%1'.</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="408"/>
      <source>&amp;Renderer</source>
      <translation>渲染器(&amp;R)</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="513"/>
      <source>Export PDF</source>
      <translation>导出PDF</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="514"/>
      <source>PDF file</source>
      <translation>PDF 文件</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="530"/>
      <source>Page sizes</source>
      <translation>页面大小</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="532"/>
      <location filename="../../DrawingView.cpp" line="545"/>
      <source>A0</source>
      <translation>A0</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="534"/>
      <location filename="../../DrawingView.cpp" line="547"/>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="536"/>
      <location filename="../../DrawingView.cpp" line="549"/>
      <source>A2</source>
      <translation>A2</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="538"/>
      <location filename="../../DrawingView.cpp" line="551"/>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="540"/>
      <location filename="../../DrawingView.cpp" line="553"/>
      <source>A4</source>
      <translation>A4</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="542"/>
      <location filename="../../DrawingView.cpp" line="555"/>
      <source>A5</source>
      <translation>A5</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="666"/>
      <source>Different orientation</source>
      <translation>不同方向</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="667"/>
      <source>The printer uses a different orientation than the drawing.
Do you want to continue?</source>
      <translation>打印机和图纸使用了不同的定位位置。你想要继续吗？</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="674"/>
      <location filename="../../DrawingView.cpp" line="682"/>
      <source>Different paper size</source>
      <translation>不同的图纸大小</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="675"/>
      <location filename="../../DrawingView.cpp" line="683"/>
      <source>The printer uses a different paper size than the drawing.
Do you want to continue?</source>
      <translation>打印机和当前图纸使用了不同大小的图纸，是否继续？</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="694"/>
      <source>Opening file failed</source>
      <translation>打开文件失败</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="695"/>
      <source>Can't open file '%1' for writing.</source>
      <translation>无法打开文件“%1”进行写入。</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::TaskOrthoViews</name>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="26"/>
      <source>Orthographic Projection</source>
      <translation>正交投影</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="46"/>
      <location filename="../../TaskOrthoViews.ui" line="71"/>
      <location filename="../../TaskOrthoViews.ui" line="96"/>
      <location filename="../../TaskOrthoViews.ui" line="121"/>
      <location filename="../../TaskOrthoViews.ui" line="146"/>
      <location filename="../../TaskOrthoViews.ui" line="177"/>
      <location filename="../../TaskOrthoViews.ui" line="202"/>
      <location filename="../../TaskOrthoViews.ui" line="227"/>
      <location filename="../../TaskOrthoViews.ui" line="252"/>
      <location filename="../../TaskOrthoViews.ui" line="277"/>
      <location filename="../../TaskOrthoViews.ui" line="302"/>
      <location filename="../../TaskOrthoViews.ui" line="362"/>
      <source>Right click for axonometric settings</source>
      <translation>单击右键设置轴测图</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="324"/>
      <source>Primary view</source>
      <translation>主视图</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="340"/>
      <source>Secondary Views</source>
      <translation>辅助视图</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="412"/>
      <source>General</source>
      <translation>常规</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="421"/>
      <source>Auto scale / position</source>
      <translation>自动缩放/定位</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="436"/>
      <source>Scale</source>
      <translation>缩放</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="468"/>
      <source>Top left x / y</source>
      <translation>左上角 x / y</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="516"/>
      <source>Spacing dx / dy</source>
      <translation>间距 dx / dy</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="561"/>
      <source>Show hidden lines</source>
      <translation>显示隐藏线</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="568"/>
      <source>Show smooth lines</source>
      <translation>显示平滑线</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="579"/>
      <source>Axonometric</source>
      <translation>轴测图</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="587"/>
      <source>Axis out and right</source>
      <translation>轴外侧靠右</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="594"/>
      <source>Vertical tilt</source>
      <translation>垂直倾斜</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="605"/>
      <location filename="../../TaskOrthoViews.ui" line="805"/>
      <source>X +ve</source>
      <translation>X 轴正向</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="610"/>
      <location filename="../../TaskOrthoViews.ui" line="685"/>
      <location filename="../../TaskOrthoViews.ui" line="810"/>
      <source>Y +ve</source>
      <translation>Y 轴正向</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="615"/>
      <location filename="../../TaskOrthoViews.ui" line="690"/>
      <location filename="../../TaskOrthoViews.ui" line="815"/>
      <source>Z +ve</source>
      <translation>Z 轴正向</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="620"/>
      <location filename="../../TaskOrthoViews.ui" line="820"/>
      <source>X -ve</source>
      <translation>X 轴负向</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="625"/>
      <location filename="../../TaskOrthoViews.ui" line="695"/>
      <location filename="../../TaskOrthoViews.ui" line="825"/>
      <source>Y -ve</source>
      <translation>Y 轴负向</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="630"/>
      <location filename="../../TaskOrthoViews.ui" line="700"/>
      <location filename="../../TaskOrthoViews.ui" line="830"/>
      <source>Z -ve</source>
      <translation>Z 轴负向</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="642"/>
      <source>Isometric</source>
      <translation>等轴测</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="647"/>
      <source>Dimetric</source>
      <translation>二轴测</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="652"/>
      <source>Trimetric</source>
      <translation>三轴测</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="660"/>
      <source> Scale</source>
      <translation> 比例</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="667"/>
      <source>View projection</source>
      <translation>视图投影</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="674"/>
      <source> Axis aligned up</source>
      <translation> 轴对齐</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="715"/>
      <location filename="../../TaskOrthoViews.ui" line="738"/>
      <source>Flip</source>
      <translation>翻转</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="728"/>
      <source> Trimetric</source>
      <translation> 三轴测</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="756"/>
      <source>Projection</source>
      <translation>投影</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="767"/>
      <source>Third Angle</source>
      <translation>第三视角投影法</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="772"/>
      <source>First Angle</source>
      <translation>第一视角投影法</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="791"/>
      <source>View from:</source>
      <translation>视图:</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="838"/>
      <source>Axis aligned right:</source>
      <translation>轴右对齐：</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::TaskProjection</name>
    <message>
      <location filename="../../TaskDialog.cpp" line="51"/>
      <source>Visible sharp edges</source>
      <translation>锐化边缘可见</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="52"/>
      <source>Visible smooth edges</source>
      <translation>平滑边缘可见</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="53"/>
      <source>Visible sewn edges</source>
      <translation>可视缝合边</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="54"/>
      <source>Visible outline edges</source>
      <translation>轮廓边缘可见</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="55"/>
      <source>Visible isoparameters</source>
      <translation>可视等角参数</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="56"/>
      <source>Hidden sharp edges</source>
      <translation>隐藏锐利边</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="57"/>
      <source>Hidden smooth edges</source>
      <translation>平滑边缘隐藏</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="58"/>
      <source>Hidden sewn edges</source>
      <translation>镶贴边缘隐藏</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="59"/>
      <source>Hidden outline edges</source>
      <translation>轮廓边缘隐藏</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="60"/>
      <source>Hidden isoparameters</source>
      <translation>隐藏iso参数</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="77"/>
      <source>Project shapes</source>
      <translation>投影形体</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="91"/>
      <source>No active document</source>
      <translation>没有活动文档</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="92"/>
      <source>There is currently no active document to complete the operation</source>
      <translation>目前尚没有活动的文档来完成该操作</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="97"/>
      <source>No active view</source>
      <translation>没有活动的视图</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="98"/>
      <source>There is currently no active view to complete the operation</source>
      <translation>目前尚没有活动的视图来完成该操作</translation>
    </message>
  </context>
  <context>
    <name>Drawing_NewPage</name>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Landscape</source>
      <translation>橫向</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="225"/>
      <source>Portrait</source>
      <translation>纵向</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="229"/>
      <source>%1%2 %3</source>
      <translation>%1%2 %3</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="234"/>
      <source>Insert new %1%2 %3 drawing</source>
      <translation>插入新的 %1%2 %3 图面</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="241"/>
      <source>%1%2 %3 (%4)</source>
      <translation>%1%2 %3 (%4)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="247"/>
      <source>Insert new %1%2 %3 (%4) drawing</source>
      <translation>插入新的 %1%2 %3 (%4) 图面</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="72"/>
      <location filename="../../Command.cpp" line="595"/>
      <source>Choose an SVG file to open</source>
      <translation>选择一个SVG文件打开</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="73"/>
      <location filename="../../Command.cpp" line="596"/>
      <location filename="../../Command.cpp" line="654"/>
      <source>Scalable Vector Graphic</source>
      <translation>可缩放矢量图形</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="327"/>
      <location filename="../../Command.cpp" line="406"/>
      <location filename="../../Command.cpp" line="456"/>
      <location filename="../../Command.cpp" line="648"/>
      <location filename="../../Command.cpp" line="772"/>
      <source>Wrong selection</source>
      <translation>选择错误</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="328"/>
      <source>Select a Part object.</source>
      <translation>选择零件对象.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="336"/>
      <location filename="../../Command.cpp" line="415"/>
      <location filename="../../Command.cpp" line="496"/>
      <location filename="../../Command.cpp" line="544"/>
      <location filename="../../Command.cpp" line="589"/>
      <location filename="../../Command.cpp" line="778"/>
      <source>No page found</source>
      <translation>没有找到页面</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="337"/>
      <location filename="../../Command.cpp" line="416"/>
      <location filename="../../Command.cpp" line="497"/>
      <location filename="../../Command.cpp" line="545"/>
      <location filename="../../Command.cpp" line="590"/>
      <location filename="../../Command.cpp" line="779"/>
      <source>Create a page first.</source>
      <translation>首先创建一个页面。</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="407"/>
      <source>Select exactly one Part object.</source>
      <translation>选择一个零部件对象。</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="457"/>
      <location filename="../../Command.cpp" line="649"/>
      <source>Select one Page object.</source>
      <translation>选择一个页对象.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="655"/>
      <source>All Files</source>
      <translation>所有文件</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="657"/>
      <source>Export page</source>
      <translation>导出页面</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="773"/>
      <source>Select exactly one Spreadsheet object.</source>
      <translation>选择一个电子表格对象。</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.cpp" line="54"/>
      <location filename="../../TaskOrthoViews.cpp" line="982"/>
      <source>Make axonometric...</source>
      <translation>创建轴测投影...</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.cpp" line="55"/>
      <location filename="../../TaskOrthoViews.cpp" line="983"/>
      <source>Edit axonometric settings...</source>
      <translation>编辑轴测图设置...</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.cpp" line="56"/>
      <location filename="../../TaskOrthoViews.cpp" line="984"/>
      <source>Make orthographic</source>
      <translation>创建正交投影</translation>
    </message>
    <message>
      <location filename="../../ViewProviderPage.cpp" line="152"/>
      <source>Show drawing</source>
      <translation>显示绘图</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="37"/>
      <source>Drawing</source>
      <translation>图纸</translation>
    </message>
  </context>
</TS>
